@@ -5,18 +5,19 @@ use crate:: {
     error::Error,
     predefined::dim,
 };
-
 use core:: {
     fmt:: { self, Debug, Display },
-    marker::PhantomData,
     ops:: { Mul, Div },
-    str::FromStr,
 };
 use const_frac::Frac;
 
+#[cfg(feature = "parser")]
+use core::marker::PhantomData;
 #[cfg(feature = "parser")]
 use combine:: { Parser as _, stream::position };
 #[cfg(feature = "default-units")]
+use core::str::FromStr;
+#[cfg(feature = "default-units")]
 use crate::predefined::unit::DEFAULT_UNIT_DEF;
 
 #[cfg(feature = "parser")]
@@ -87,7 +88,9 @@ impl Default for Conv {
     }
 }
 
-/// Unit
+/// Representation of Unit
+///
+/// Holding the coefficients for converting to the base unit and dimension.
 pub struct Unit<R, D> {
     pub a: R,
     pub b: R,
@@ -262,7 +265,7 @@ where
     }
 }
 
-/// Runtime parsing for unit string by using default unit definision.
+/// Runtime parsing for unit string by using default unit definition.
 ///
 /// For the syntax of unit strring, see [Parser] documentation.
 ///
@@ -303,6 +306,7 @@ where
 /// > &nbsp;&nbsp; | `·`<sup>`\u{00B7}`</sup> | `×`<sup>`\u{00D7}`</sup> | `•`<sup>`\u{2022}`</sup>\
 /// > &nbsp;&nbsp; | `∙`<sup>`\u{2219}`</sup> | `⋅`<sup>`\u{22C5}`</sup> | `✕`<sup>`\u{2715}`</sup>\
 /// > &nbsp;&nbsp; | `✖`<sup>`\u{2716}`</sup> | `・`<sup>`\u{30FB}`</sup> | `･`<sup>`\u{FF65}`</sup>
+/// > &nbsp;&nbsp; | `毎`<sup>`\u{6BCE}}`</sup>
 /// >
 /// > _Product_ :\
 /// > &nbsp;&nbsp; ( _Element_ _Delimiter_<sup>\*</sup> )<sup>+</sup>\
@@ -323,14 +327,14 @@ where
 /// >
 /// The unit string is divided into numerator and denominator by _Slash_.
 /// The denominator is optional.
-/// The numerator and denominator are composed as a product of _Element_ s.
-/// Each _Element_ s in the product need to be delimited explicitly.
-/// Each _Element_ s are composed of [_Name_](#name) with SI [_Prefix_](#prefix) and _Exponent_.
+/// The numerator and denominator are composed as a product of _Element_  s.
+/// Each _Element_  s in the product need to be delimited explicitly.
+/// Each _Element_  s are composed of [_Name_](#name) with SI [_Prefix_](#prefix) and _Exponent_.
 /// SI _Prefix_ and _Exponent_ are optional.
 ///
 /// ## Name
-/// _Name_ consists of any unicode [char] except follwings.
-/// - [char]s composing _Delemeter_.
+/// _Name_ consists of any Unicode [char] except the followings.
+/// - [char]s composing _Delimiter_.
 /// - [char]s composing _Slash_.
 /// - [char]s composing _Exponent_.
 /// - parentheses
@@ -338,8 +342,8 @@ where
 ///     - `(` `)`
 ///     - `{` `}`
 ///     - `<` `>`<br>
-///     Square brackets are used for marking _Modifiers_.
-///     Any other parentheses has no meanings in this syntax.
+///     Square brackets mark up _Modifier_.
+///     Any other parentheses have no meanings in this syntax.
 ///     So, these parentheses should not appear in the unit string.
 ///
 /// Parser looks up this _Name_ in the array set to `tbl` member.
@@ -365,7 +369,7 @@ where
 /// For example, when the foot (ft) and ton (t) defined the definition table,
 /// `ft` matches femto ton (same as nano gram (`ng`))!!
 /// Therefore, the foot is defined as `ft.` in the [default definition](crate::predefined::unit::DEFAULT_UNIT_DEF).
-/// The period can consist of _Name_.
+/// The period can compose of _Name_.
 #[cfg(feature = "parser")]
 #[cfg_attr(docsrc, doc(cfg(feature = "parser")))]
 pub struct Parser<K, T>
